/*******************************************************************************
 * Copyright (c) 2008 Marian Schedenig
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Marian Schedenig - initial API and implementation
 *******************************************************************************/ 

package com.musgit.eclipse.grepconsole.model;

import java.util.ArrayList;
import java.util.List;

/**
 * Stores persistent Grep Console settings.
 * 
 * @author msched
 */
public class GrepConsoleSettings
{
	/** A list of grep expressions. */
	protected List<GrepExpression> expressions = new ArrayList<GrepExpression>();
	
	/**
	 * Adds a new grep expression.
	 * 
	 * @param expression New expression.
	 */
	public void addExpression(GrepExpression expression)
	{
		expressions.add(expression);
	}

	/**
	 * Adds a new grep expression as the first expression.
	 * 
	 * @param expression New expression.
	 */
	public void addExpressionAsFirst(GrepExpression expression)
	{
		expressions.add(0, expression);
	}
	
	/**
	 * Removes a grep expression.
	 * 
	 * @param expression Expression to be removed.
	 * 
	 * @return <code>true</code> iff the expression was removed.
	 */
	public boolean removeExpression(GrepExpression expression)
	{
		return expressions.remove(expression);
	}
	
	/**
	 * Returns the list of grep expressions.
	 * 
	 * <emp>Warning:</emp> The returned list is a reference to the original list
	 * instance and should therefore not be changed. No copy is created for
	 * performance reasons.
	 * 
	 * @return List of grep expressions. 
	 */
	public List<GrepExpression> getExpressions()
	{
		return expressions;
	}
	
	/**
	 * Replaces the current list of grep expressions.
	 * 
	 * @param expressions New list of grep expressions. A copy of this list is
	 * 		created automatically.  
	 */
	public void setExpressions(List<GrepExpression> expressions)
	{
		this.expressions = new ArrayList<GrepExpression>();
		
		for(GrepExpression color: expressions)
		{
			this.expressions.add(color.clone());
		}
	}
	
	/*
	 * (non-Javadoc)
	 * @see java.lang.Object#clone()
	 */
	@Override
	public GrepConsoleSettings clone()
	{
		GrepConsoleSettings clone = new GrepConsoleSettings();
		
		for(GrepExpression expression: expressions)
		{
			clone.expressions.add(expression.clone());
		}
		
		return clone;
	}
}
