/*******************************************************************************
 * Copyright (c) 2008 Marian Schedenig
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Marian Schedenig - initial API and implementation
 *******************************************************************************/ 

package com.musgit.eclipse.grepconsole.model;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.RGB;

/**
 * A style is used for either an entire line matched by a grep expression, or
 * for the part of a line that is matched by an expression's capture group.
 * 
 * @author msched
 */
public class GrepStyle
{
	/** Foreground color. */
	private RGB foreground;
	
	/** Background color. */
	private RGB background;
	
	/** Font style. Valid values are SWT.BOLD and SWT.ITALIC plus combinations. */
	private int fontStyle;
	
	/** Whether to underline. */
	private boolean underline;
	
	/** Underline color. When none is set, the text colour is used. */
	private RGB underlineColor;
	
	/** Whether to strikeout. */
	private boolean strikeout;

	/** Strikeout color. When none is set, the text colour is used. */
	private RGB strikeoutColor;
	
	/** Whether to draw a border. */
	private boolean border;
	
	/** Border color. When none is set, the text colour is used. */
	private RGB borderColor;
	
	/** Number of pixels by which text should be offset from the baseline. */
	private int rise;
	
	/**
	 * Creates a new, empty style.
	 */
	public GrepStyle()
	{
		foreground = null;
		background = null;
		fontStyle = SWT.NONE;
	}
	
	/**
	 * Creates a new style.
	 * 
	 * @param foreground Foreground color.
	 * @param background Background color.
	 * @param fontStyle Font style.
	 */
	public GrepStyle(RGB foreground, RGB background, int fontStyle)
	{
		this.foreground = foreground;
		this.background = background;
		this.fontStyle = fontStyle;
	}

	/**
	 * Creates a copy of an existing style.
	 * 
	 * @param src Source style.
	 */
	private GrepStyle(GrepStyle src)
	{
		this.foreground = src.foreground;
		this.background = src.background;
		this.fontStyle = src.fontStyle;
		this.underline = src.underline;
		this.underlineColor = src.underlineColor;
		this.strikeout = src.strikeout;
		this.strikeoutColor = src.strikeoutColor;
		this.border = src.border;
		this.borderColor = src.borderColor;
		this.rise = src.rise;
	}

	/*
	 * (non-Javadoc)
	 * @see java.lang.Object#clone()
	 */
	@Override
	public GrepStyle clone()
	{
		return new GrepStyle(this);
	}

	public RGB getForeground()
	{
		return foreground;
	}

	public void setForeground(RGB foreground)
	{
		this.foreground = foreground;
	}

	public RGB getBackground()
	{
		return background;
	}

	public void setBackground(RGB background)
	{
		this.background = background;
	}

	public int getFontStyle()
	{
		return fontStyle;
	}

	public void setFontStyle(int fontStyle)
	{
		this.fontStyle = fontStyle;
	}

	public RGB getUnderlineColor()
	{
		return underlineColor;
	}

	public void setUnderlineColor(RGB underlineColor)
	{
		this.underlineColor = underlineColor;
	}

	public boolean isStrikeout()
	{
		return strikeout;
	}

	public void setStrikeout(boolean strikeout)
	{
		this.strikeout = strikeout;
	}

	public RGB getStrikeoutColor()
	{
		return strikeoutColor;
	}

	public void setStrikeoutColor(RGB strikeoutColor)
	{
		this.strikeoutColor = strikeoutColor;
	}

	public RGB getBorderColor()
	{
		return borderColor;
	}

	public void setBorderColor(RGB borderColor)
	{
		this.borderColor = borderColor;
	}

	public int getRise()
	{
		return rise;
	}

	public void setRise(int rise)
	{
		this.rise = rise;
	}

	public boolean isUnderline()
	{
		return underline;
	}

	public void setUnderline(boolean underline)
	{
		this.underline = underline;
	}

	public boolean isBorder()
	{
		return border;
	}

	public void setBorder(boolean border)
	{
		this.border = border;
	}
}
