/*******************************************************************************
 * Copyright (c) 2008 Marian Schedenig
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Marian Schedenig - initial API and implementation
 *******************************************************************************/ 

package com.musgit.eclipse.grepconsole.util;

import java.util.Random;

import org.eclipse.swt.graphics.RGB;

/**
 * Utility methods for RGB objects.
 * 
 * @author msched
 */
public class RGBUtil
{
	/** Used for random numbers. */
	private static Random random = new Random();
	
	/**
	 * Creates a random RGB value.
	 * 
	 * @return Random RGB value.
	 */
	public static RGB getRandomRgb()
	{
		return new RGB(128 + random.nextInt(128), 128 + random.nextInt(128), 128 + random.nextInt(128));
	}

	/**
	 * Converts an RGB instance to a 6-digit hex string.
	 * 
	 * @param color RGB instance to convert.
	 * 
	 * @return String representation of the RGB instance, or an empty string if
	 * 		color was <code>null</code>.
	 */
	public static String rgbToString(RGB color)
	{
		if(color == null)
		{
			return "";
		}
		else
		{
			return StringUtil.intHexString(color.red, 2) + 
				StringUtil.intHexString(color.green, 2) +
				StringUtil.intHexString(color.blue, 2);
		}
	}

	/**
	 * Parses a string into an RGB instance. The string should be a 6-digit hex
	 * representation of the RGB value. Longer strings are truncated, shorter
	 * strings are padded with zeroes from the left.
	 * 
	 * @param s String representation.
	 * 
	 * @return RGB instance, or <code>null</code> if the provided string was empty
	 *     or <code>null</code>.
	 *     
	 * @throws NumberFormatException If the provided string could not be parsed.
	 */
	public static RGB stringToRgb(String s) throws NumberFormatException
	{
		if(s == null || s.length() == 0)
		{
			return null;
		}
		
		if(s.length() != 6)
		{
			s = ("000000" + s);
			s = s.substring(s.length() - 6);
		}
		
		return new RGB(Integer.parseInt(s.substring(0, 2), 16),
				Integer.parseInt(s.substring(2, 4), 16),
				Integer.parseInt(s.substring(4, 6), 16));
	}
}
