/*******************************************************************************
 * Copyright (c) 2008 Marian Schedenig
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Marian Schedenig - initial API and implementation
 *******************************************************************************/ 

package com.musgit.eclipse.grepconsole.actions;

import java.util.regex.Pattern;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.text.TextSelection;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbench;

import com.musgit.eclipse.grepconsole.Activator;
import com.musgit.eclipse.grepconsole.manageexpressions.ManageExpressionsDialog;

/**
 * Adds a new Grep Expression matching the text currently selected in the
 * console. The expression is assigned a random background colour for the entire
 * line, and a bold font for the highlighted text.
 *  
 * @author msched
 */
public class AddGrepExpressionAction implements IViewActionDelegate
{
	/** The currently selected string. */
	private String selected = null;

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
	 */
//	@Override
	public void init(IViewPart view)
	{
	}

	/**
	 * Tracks the current selection and stores the selected string. The action is
	 * enabled only if the selection is not empty and does not span multiple
	 * lines.
	 * 
	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction, org.eclipse.jface.viewers.ISelection)
	 */
//	@Override
	public void selectionChanged(IAction action, ISelection selection)
	{
		selected = null;
		
		if(selection instanceof TextSelection)
		{
			TextSelection ts = (TextSelection) selection;
			
			if(ts.getStartLine() == ts.getEndLine() && ts.getText().length() > 0)
			{
				selected  = ts.getText();
			}
		}
		
		action.setEnabled(selected != null);
	}

	/**
	 * Silently opens the settings dialog and adds a new expression according to
	 * the current selection.
	 * 
	 * TODO: When we support multiple persistent configurations, this should
	 * access the current console to determine which setting is to be edited.
	 * 
	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
	 */
//	@Override
	public void run(IAction action)
	{
		Activator plugin = Activator.getDefault();
		IWorkbench workbench = plugin.getWorkbench();
		Shell shell = workbench.getActiveWorkbenchWindow().getShell();
		
		ManageExpressionsDialog dlg = new ManageExpressionsDialog(shell);
		dlg.create();
		dlg.addExpression(".*(" + Pattern.quote(selected) + ").*");
		dlg.okPressed();
		plugin.saveSettings();
	}
}
