/*******************************************************************************
 * Copyright (c) 2008 Marian Schedenig
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Marian Schedenig - initial API and implementation
 *******************************************************************************/ 

package com.musgit.eclipse.grepconsole.editexpression;

import java.util.regex.Matcher;
import java.util.regex.Pattern;
import java.util.regex.PatternSyntaxException;

import org.eclipse.jface.viewers.IStructuredContentProvider;
import org.eclipse.jface.viewers.Viewer;

/**
 * A content provider listing group names for an expression.
 * 
 * @author msched
 */
public class GroupsContentProvider implements IStructuredContentProvider 
{
	/** Current expression. */
	private String expression;
	
	/** Number of capture groups in current expression. */
	private int groupCount;
	
	/** Group names for the current expression. */
	private String[] elements;

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.jface.viewers.IContentProvider#dispose()
	 */
//	@Override
	public void dispose()
	{
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.jface.viewers.IContentProvider#inputChanged(org.eclipse.jface.viewers.Viewer, java.lang.Object, java.lang.Object)
	 */
//	@Override
	public void inputChanged(Viewer viewer, Object oldInput, Object newInput)
	{
		if(newInput == null)
		{
			return;
		}
		
		expression = (String) newInput;
		Pattern pattern = null;
		
		try
		{
			pattern = Pattern.compile(expression);
		}
		catch(PatternSyntaxException ex)
		{
		}
		
		if(pattern != null)
		{
			Matcher matcher = pattern.matcher("");
			groupCount = matcher.groupCount();
			
			elements = new String[groupCount + 1];
			elements[0] = "Whole line";
			
			for(int i = 1; i <= groupCount; i++)
			{
				elements[i] = "Group " + i;
			}
		}
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.jface.viewers.IStructuredContentProvider#getElements(java.lang.Object)
	 */
//	@Override
	public Object[] getElements(Object inputElement)
	{
		return elements;
	}
}
