/*******************************************************************************
 * Copyright (c) 2008 Marian Schedenig
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Marian Schedenig - initial API and implementation
 *******************************************************************************/ 

package com.musgit.eclipse.grepconsole.participants;

import org.eclipse.swt.custom.StyledText;
import org.eclipse.ui.console.IConsole;
import org.eclipse.ui.console.IConsolePageParticipant;
import org.eclipse.ui.part.IPageBookViewPage;

import com.musgit.eclipse.grepconsole.Activator;

/**
 * Adds a line background listener to all consoles containing styled text.
 * Responsible for adding a GrepConsoleStyleListener to new consoles.
 *  
 * @author msched
 */
public class GrepPageParticipant implements IConsolePageParticipant
{
	/*
	 * (non-Javadoc)
	 * @see org.eclipse.ui.console.IConsolePageParticipant#activated()
	 */
//	@Override
	public void activated()
	{
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.ui.console.IConsolePageParticipant#deactivated()
	 */
//	@Override
	public void deactivated()
	{
	}

	/**
	 * Removes the viewer from the plugin's viewer map on disposal.
	 * 
	 * @see org.eclipse.ui.console.IConsolePageParticipant#dispose()
	 */
//	@Override
	public void dispose()
	{
		Activator.getDefault().removeViewers(this);
	}

	/**
	 * When initialising a participant for a console containing styled text, a
	 * GrepConsoleStyleListener is attached to the console's viewer.
	 * 
	 * @see org.eclipse.ui.console.IConsolePageParticipant#init(org.eclipse.ui.part.IPageBookViewPage, org.eclipse.ui.console.IConsole)
	 */
//	@Override
	public void init(IPageBookViewPage page, IConsole console)
	{
//		System.out.println("Initialising GrepPageParticipant for page: " + page + "; console: " + console);
		
		if(page.getControl() instanceof StyledText)
		{
			StyledText viewer = (StyledText)(page.getControl());
			Activator.getDefault().setViewer(viewer, this);
			
			viewer.addLineStyleListener(new GrepConsoleStyleListener());
		}
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.core.runtime.IAdaptable#getAdapter(java.lang.Class)
	 */
	@SuppressWarnings("unchecked")
//	@Override
	public Object getAdapter(Class adapter)
	{
		return null;
	}
}
