/*******************************************************************************
 * Copyright (c) 2008 Marian Schedenig
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Marian Schedenig - initial API and implementation
 *******************************************************************************/ 

package com.musgit.eclipse.grepconsole.util;

/**
 * Utility methods for strings.
 * 
 * @author msched
 */
public class StringUtil
{
	/**
	 * Returns the provided string, but returns <code>null</code> for empty
	 * strings.
	 * 
	 * @param s String.
	 * 
	 * @return The string, or <code>null</code>.
	 */
	public static String stringOrNull(String s)
	{
		return (s == null || s.length() == 0) ? null : s;
	}

	/**
	 * Converts an integer value to a hex string.
	 * 
	 * @param value Integer value.
	 * @param length Number of digits for the hex string. Shorter strings will be
	 *     padded with zeroes.
	 *     
	 * @return Hex string representation.
	 */
	public static String intHexString(int value, int length)
	{
		String hex = Integer.toHexString(value);
		
		if(hex.length() < length)
		{
			StringBuffer sb = new StringBuffer("0");
			
			for(int i = sb.length() + hex.length(); i < length; i++)
			{
				sb.append('0');
			}
			
			sb.append(hex);
			hex = sb.toString();
		}
		
		return hex;
	}
}
